/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *      ___            __                   __
 *     / __`\         /  _\                /\ \ 
 *    /\ \/\ \  _ __ /\ \_/    ___     __  \_\ \__
 *    \ \ \ \ \/\`'__\_\ \__  /'__`\ /`___\/\__  _\ 
 *     \ \ \_\ \ \ \//\__  _\/\  __//\____ \/_/\ \/_
 *      \ \____/\ \_\\/_/\ \/\ \____\/_____/  \ \___\ 
 *       \/___/  \/_/   \_\ \ \/____/_____/    \/__/
 *                      /\__/
 *                      \/_/
 */

/**
 * @file
 * @author  Nikolay Kurtov <nkurtov@gmail.com>
 *
 * @brief Calculator.
 */

#ifndef CALCULATOR_H
#define CALCULATOR_H

#include <QThread>
#include <QVector>
class QMutex;

#include "point.h"

/** Calculator. */
class Calculator : public QThread{
		Q_OBJECT
		
private:
	static const int MAX_POINTS = 2500000;
	bool running;
	int iteration;
	double temperature;
	int steps;
	double cooling;
	int freezes;
	
	QVector<Point> points;
	int* currentSolution;
	int* bestSolution;
	
	double currentResult;
	double bestResult;
	
	int resCount;
	double* resPoints;
	
	QMutex* mutex;
	
public:
	Calculator();
	~Calculator();
	void setPoints(const QVector<Point>& aPoints);
private:
	virtual void run();
	void calculateLength();
	void getNextSolution();
	void getSolutionAType();
	void getSolutionBType();
	void mix (int first, int second);
		
public slots:
	void runRecved(double aTemperature, int aSteps, double aCooling, int aFreezes);
	void stopRecved();
	
public:
	const QVector<Point>& getPoints() const {
		return this->points;
	}
	int* const * getCurrentSolutionPtr() const{
		return &this->currentSolution;
	}
	int getIteration() const{
		return this->iteration;
	}
	double getTemperature() const{
		return this->temperature;
	}
	double getCurrentResult() const {
		return this->currentResult;
	}
	double getBestResult() const {
		return this->bestResult;
	}
	int getFreezes() const{
		return this->freezes;
	}
	const int* getCurrentSolution() const {
		return this->currentSolution;
	}
	const int* getBestSolution() const {
		return this->bestSolution;
	}
	int getResCount() const {
		return this->resCount;
	}
	const double* getResPoints() const {
		return this->resPoints;
	}
	QMutex* getMutex() {
		return this->mutex;
	}
};

#endif
