/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>. 
 */

/* Authors:
 *   Nikolay Kurtov <nkurtov@gmail.com>
 *   Serguey G Basalaev <sbasalaev@gmail.com>
 *      ___            __                   __
 *     / __`\         /  _\                /\ \ 
 *    /\ \/\ \  _ __ /\ \_/    ___     __  \_\ \__
 *    \ \ \ \ \/\`'__\_\ \__  /'__`\ /`___\/\__  _\ 
 *     \ \ \_\ \ \ \//\__  _\/\  __//\____ \/_/\ \/_
 *      \ \____/\ \_\\/_/\ \/\ \____\/_____/  \ \___\ 
 *       \/___/  \/_/   \_\ \ \/____/_____/    \/__/
 *                      /\__/
 *                      \/_/
 */        

#include <QApplication>
#include <QTranslator>
#include <QLocale>

#include "osdef.h"
#include "mainWindow.h"

#ifndef __VERSION__
#define __VERSION__ "unknown"
#endif

int main(int argc, char* argv[]) {
	QApplication app(argc, argv);
	
	//load translation that corresponds to the locale
	QTranslator qtTranslator;
    QString transfile = QString(OS_TRANSL_PATH)+QString("tspflaming_")+QLocale::system().name();
    qtTranslator.load(transfile, app.applicationDirPath());
    app.installTranslator(&qtTranslator);

//inside the procedure, otherwise won't be translated
const QString HELP_MESSAGE = MainWindow::tr(
"Usage:\n\
\ttspflaming [options] [filename]\n\n\
Options:\n\
\t--help, -h\tshow this message and exit\n\
\t--version, -v\tshow program version and exit\n\
");

	//parse parameters
	//on Windows output to the console won't work for GUI app, so we show message box
	int argnum = 0;
	while (++argnum < argc) {
		QString argstr(argv[argnum]);
		if (!argstr.startsWith('-')) break;
		if (!argstr.compare("--")) {
			argnum++;
			break;
		}
		if (!argstr.compare("--help") || !argstr.compare("-h")) {
			OS_PRINTOUT(HELP_MESSAGE)
			return 0;
		}
		if (!argstr.compare("--version") || !argstr.compare("-v")) {
			QString versions = MainWindow::tr("TSP Flaming version: %1\n").arg(MainWindow::VERSION);
			versions += MainWindow::tr("Uses Qt: %1\n").arg(QT_VERSION_STR);
			versions += MainWindow::tr("Built with compiler: %1\n").arg(__VERSION__);
			OS_PRINTOUT(versions);
			return 0;
		}
		OS_PRINTOUT(MainWindow::tr("Unknown option: %1\n").arg(argstr));
	}
	
	//get filename
	QString filename = QString();
	if (argnum < argc) filename = QString(argv[argnum]);

	//start
	MainWindow* mainWindow = new MainWindow(filename);
	mainWindow->show();
	return app.exec();
}
