/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *      ___            __                   __
 *     / __`\         /  _\                /\ \ 
 *    /\ \/\ \  _ __ /\ \_/    ___     __  \_\ \__
 *    \ \ \ \ \/\`'__\_\ \__  /'__`\ /`___\/\__  _\ 
 *     \ \ \_\ \ \ \//\__  _\/\  __//\____ \/_/\ \/_
 *      \ \____/\ \_\\/_/\ \/\ \____\/_____/  \ \___\ 
 *       \/___/  \/_/   \_\ \ \/____/_____/    \/__/
 *                      /\__/
 *                      \/_/
 */

/**
 * @file
 * @author  Nikolay Kurtov <nkurtov@gmail.com>
 * @author  Serguey Basalaev <sbasalaev@gmail.com>
 *
 * @brief Application main window.
 */

#ifndef MAIN_WINDOW_H
#define MAIN_WINDOW_H

#include <QMainWindow>

#include "ui_superMainWindow.h"
#include "calculator.h"
#include "task.h"

class QTimer;

/** Application main window. */
class MainWindow : public QMainWindow, private Ui::SuperMainWindow {
		Q_OBJECT

private:
	static const int STATUS_BAR_DELAY = 2000;
	bool running;
	Calculator* calculator;
	QTimer* timer;
	Task* task;
	int oldSteps;
	
public:
	static const QLatin1String NAME;
	static const QLatin1String VERSION;
	MainWindow(const QString& filename);
private:
	bool loadFile(const QString& fileName);
	bool saveFile(const QString& fileName);
	void updateMapTable();
	void addTaskPoint(const Point& point);

public slots:
	void calculatorStopped();

private slots:
	void open();
	void save();
	void triggerCalculations();
	void updateData();
	void about();
	void aboutQt();
	void help();
	void removeTaskPoint();
	void addTaskPoint();
	void verifyCell(QTableWidgetItem*);

signals:
	void runCalculator(double temperature, int steps, double cooling, int freezes);
	void stopCalculator();
	void nameChanged(const QString&);
	void commentsChanged(const QString&);
};

#endif
