/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>. 
 */

/* Author: Nikolay Kurtov <nkurtov@gmail.com>
 *      ___            __                   __
 *     / __`\         /  _\                /\ \ 
 *    /\ \/\ \  _ __ /\ \_/    ___     __  \_\ \__
 *    \ \ \ \ \/\`'__\_\ \__  /'__`\ /`___\/\__  _\ 
 *     \ \ \_\ \ \ \//\__  _\/\  __//\____ \/_/\ \/_
 *      \ \____/\ \_\\/_/\ \/\ \____\/_____/  \ \___\ 
 *       \/___/  \/_/   \_\ \ \/____/_____/    \/__/
 *                      /\__/
 *                      \/_/
 */        

#include "mapArea.h"

#include <QPoint>
#include <QPainter>
#include <QMutex>

MapArea::MapArea(QWidget*& widget) : QWidget(widget), solutionPtr(NULL), oldWidth(-1), oldHeight(-1), mutex(NULL){
	this->points.clear();
	this->dpoints.clear();
}

void MapArea::setPoints(const QVector<Point>& aPoints){
	this->points = aPoints;
	this->maxX = -100000;
	this->maxY = -100000;
	this->minX = 100000;
	this->minY = 100000;
	for (int index = 0; index < this->points.size(); index++){
		double x = this->points[index].getX();
		double y = this->points[index].getY();
		if (x > this->maxX){
			this->maxX = x;
		}
		if (x < this->minX){
			this->minX = x;
		}
		if (y > this->maxY){
			this->maxY = y;
		}
		if (y < this->minY){
			this->minY = y;
		}
	}
}

void MapArea::setSolutionPtr(int* const* aSolutionPtr){
	this->solutionPtr = aSolutionPtr;
}

void MapArea::setMutex(QMutex* aMutex){
	this->mutex = aMutex;
}

void MapArea::paintEvent(QPaintEvent*){
        QPainter painter(this);
        int size = this->points.size();
        int currentWidth = this->width();
        int currentHeight = this->height();
        if (currentHeight == this->oldHeight && currentWidth == this->oldWidth && this->dpoints.size() == size){
                if (!this->solutionPtr || *(this->solutionPtr) == NULL){
                        for (int index = 0; index < size; index++){
                                int rindex = index;
                                painter.drawPoint(this->dpoints[rindex]);
                        }
                } else {
                        this->mutex->lock();
                        int* solution = *(this->solutionPtr);
                        for (int index = 0; index < size-1; index++){
                                painter.drawLine(this->dpoints[solution[index]], this->dpoints[solution[index+1]]);
                        }
                        painter.drawLine(this->dpoints[solution[size-1]], this->dpoints[solution[0]]);
                        this->mutex->unlock();
                }
        } else {
                double mmx = currentWidth / double(this->maxX - this->minX);
                double mmy = currentHeight/ double(this->maxY - this->minY);
                this->dpoints.resize(size);
                if (!this->solutionPtr || *(this->solutionPtr) == NULL){
                        for (int index = 0; index < size; index++){
                                int rindex = index;
                                double x = this->points[rindex].getX();
                                double y = this->points[rindex].getY();
                                int px = qRound((x - this->minX) * mmx);
                                int py = qRound((y - this->minY) * mmy);
                                painter.drawPoint(px, py);
                                QPoint dpoint(px, py);
                                this->dpoints[rindex] = dpoint;
                        }
                } else {
                        for (int index = 0; index < size; index++){
                                int rindex = index;
                                double x = this->points[rindex].getX();
                                double y = this->points[rindex].getY();
                                int px = qRound((x - this->minX) * mmx);
                                int py = qRound((y - this->minY) * mmy);
                                QPoint dpoint(px, py);
                                this->dpoints[rindex] = dpoint;
                        }
                        this->mutex->lock();
                        int* solution = *(this->solutionPtr);
                        for (int index = 0; index < size-1; index++){
                                painter.drawLine(this->dpoints[solution[index]], this->dpoints[solution[index+1]]);
                        }
                        painter.drawLine(this->dpoints[solution[size-1]], this->dpoints[solution[0]]);
                        this->mutex->unlock();
                }
                this->oldWidth = currentWidth;
                this->oldHeight = currentHeight;
        }
}
