/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file
 * @author  Serguey Basalaev <sbasalaev@gmail.com>
 *
 * @brief Macro definitions specific to the target OS.
 * <table border="0">
 *   <tr>
 *     <td><b>Macro</b></td>
 *     <td><b>Description</b></td>
 *   </tr>
 *   <tr>
 *     <td><c>OS_TRANSL_PATH</b></c></td>
 *     <td>The path to the translation files, a quoted string.</td>
 *   </tr>
 *   <tr>
 *     <td><c>OS_PRINTOUT(<i>str</i>)</c></td>
 *     <td>Used to print some useful information. In Linux uses console,
 *       in Windows <c>MessageBox</c>.</td>
 *   </tr>
 * </table>
 */

#ifndef OSDEF_H
#define OSDEF_H

#ifdef Q_OS_LINUX

 /** The path to the translation files.
  * Adjusted to fit within Linux file system hierarchy.
  */
 #define OS_TRANSL_PATH "../share/tspflaming/translations/"
 
 #include <stdio.h>
 #include <QTextStream>

 /** Used to print some useful information.
  * Output is printed to the Linux console.
  * @param str <c>const char *</c> or <c>QString</c>
  */
 #define OS_PRINTOUT(str)  QTextStream(stdout) << (str);

#else /* not Linux */

 /** The path to the translated files. */
 #define OS_TRANSL_PATH "./Translations/"
 
 #include <QMessageBox>
 #include "mainWindow.h"
 
 /** Used to print some useful information.
  * Prints information in system independant way - using a <c>MessageBox</c>.
  * @param str a string to print, <c>(const char *)</c> or <c>QString</c>
  */
 #define OS_PRINTOUT(str)  QMessageBox::information(NULL, MainWindow::NAME, (str));
 
#endif

#endif /* OSDEF_H */
