/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>. 
 */

/* Author: Nikolay Kurtov <nkurtov@gmail.com>
 *      ___            __                   __
 *     / __`\         /  _\                /\ \ 
 *    /\ \/\ \  _ __ /\ \_/    ___     __  \_\ \__
 *    \ \ \ \ \/\`'__\_\ \__  /'__`\ /`___\/\__  _\ 
 *     \ \ \_\ \ \ \//\__  _\/\  __//\____ \/_/\ \/_
 *      \ \____/\ \_\\/_/\ \/\ \____\/_____/  \ \___\ 
 *       \/___/  \/_/   \_\ \ \/____/_____/    \/__/
 *                      /\__/
 *                      \/_/
 */        

#include "paintArea.h"

#include <QPainter>

PaintArea::PaintArea(QWidget*& widget) : QWidget(widget), points(NULL), pointsNumber(0), maxResult(1.0){
}

void PaintArea::setPoints(const double* aPoints){
	this->points = aPoints;
}

void PaintArea::setPointsNumber(int number){
	for (int index = this->pointsNumber; index < number; index++){
		if (this->points[index] > this->maxResult){
			this->maxResult = this->points[index];
		}
	}
	this->pointsNumber = number;
}

void PaintArea::reset(){
	this->pointsNumber = 0;
	this->maxResult = 1.0;
}

void PaintArea::paintEvent(QPaintEvent*){
	QPainter painter(this);
	double _size = 1.0 / double(this->pointsNumber);
	double r_maxResult = 1.0 / double(this->maxResult);
	int currentWidth = width();
	int currentHeight = height();
	double _size_width = currentWidth * _size;
	for (int index = 0; index < this->pointsNumber; index++){
		double result = this->points[index];
		painter.drawPoint(int(index * _size_width), int((1.0 - result * r_maxResult) * currentHeight));
	}
}
