/* This file is a part of TSP Flaming
 *  Copyright (C) 2008-2010 Nikolay Kurtov <nkurtov@gmail.com>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file
 * @author  Serguey Basalaev <sbasalaev@gmail.com>
 *
 * @section DESCRIPTION
 *
 * @brief TSP task.
 */

#ifndef TASK_H
#define TASK_H

#include <QObject>
#include <QVector>
#include <QString>
#include <QFile>
#include "point.h"

/**
 * TSP task.
 * Holds points and some descriptive information.
 */
class Task : public QObject{
		
private:
	QString fName;
	QString fComments;
	int fDimension;
	QVector<Point> fPoints;
public:
	Task(){}
	~Task(){}
	QString name() const;
	QString comments() const;
	int dimension() const;
	const QVector<Point>& points() const;
	bool load(const QString& fileName);
	bool save(const QString& fileName);
	void addPoint(const Point& point);
	void modifyPoint(int pos, const Point& point);
	void removePoint(int pos);
	void setName(const QString& name);
	void setComments(const QString& comments);
};

#endif /* TASK_H */
