; TSP Flaming NSIS script
;  Copyright (C) 2009-2010 Nikolay Kurtov <nkurtov@gmail.com>
;  Author: Serguey Basalaev <sbasalaev@gmail.com>
;
;  This program is free software: you can redistribute it and/or modify
;  it under the terms of the GNU General Public License as published by
;  the Free Software Foundation, either version 3 of the License, or
;  any later version.
;
;  This program is distributed in the hope that it will be useful,
;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;  GNU General Public License for more details.
; 
;  You should have received a copy of the GNU General Public License
;  along with this program.  If not, see <http://www.gnu.org/licenses/>. 

;-- Project Definitions --
!define Target      "tspflaming"
!define Title       "TSP Flaming"
!define Version     "1.2"
!define Vendor      "Nikolay Kurtov"
!define Description "A solution of TSP"
!define URL         "http://tspflaming.sourceforge.net"

;-- registry keys --
!define RegKey      "Software\${Title}"
!define RegInstPath "InstallPath"
!define RegSMPath   "StartMenuPath"
!define RegSysUnKey "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${Title}"

;-- Variables --
Var StartMenuDir

;-- Defining Modern UI --
!include "MUI.nsh"

!define MUI_ABORTWARNING

!define MUI_ICON                       "${NSISDIR}\Contrib\Graphics\Icons\orange-install.ico"
!define MUI_UNICON                     "${NSISDIR}\Contrib\Graphics\Icons\orange-uninstall.ico"
!define MUI_WELCOMEFINISHPAGE_BITMAP   "${NSISDIR}\Contrib\Graphics\Wizard\orange.bmp"
!define MUI_UNWELCOMEFINISHPAGE_BITMAP "${NSISDIR}\Contrib\Graphics\Wizard\orange-uninstall.bmp"
!define MUI_HEADERIMAGE
!define MUI_HEADERIMAGE_BITMAP         "${NSISDIR}\Contrib\Graphics\Header\orange.bmp"

!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "COPYING"
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_STARTMENU "Application" $StartMenuDir
!insertmacro MUI_PAGE_INSTFILES

!insertmacro MUI_UNPAGE_WELCOME
!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

!insertmacro MUI_LANGUAGE "English"
!insertmacro MUI_LANGUAGE "Russian"
!insertmacro MUI_LANGUAGE "Korean"

;-- Install section -- 
Section "Install"
	;installing distribution
	SetOutPath "$INSTDIR"
	File "build\${Target}.exe"
	File "build\mingwm10.dll"
	File "build\QtCore4.dll"
	File "build\QtGui4.dll"
	File "build\QtSvg4.dll"
	File "/oname=COPYING.txt" "COPYING"
	File /r "build\Examples"
	File /r "build\Translations"
	;installing uninstaller
	WriteUninstaller "$INSTDIR\Uninstall.exe"
	;installing start menu entries
	CreateDirectory "$SMPROGRAMS\$StartMenuDir"
	CreateShortcut "$SMPROGRAMS\$StartMenuDir\${Title}.lnk" "$INSTDIR\${Target}.exe"
	CreateShortcut "$SMPROGRAMS\$StartMenuDir\Uninstall.lnk" "$INSTDIR\Uninstall.exe"
	;registry keys
	WriteRegStr HKLM "${RegKey}" "${RegInstPath}" "$INSTDIR"
	WriteRegStr HKLM "${RegKey}" "${RegSMPath}"   "$StartMenuDir"
	;system uninstall registry entry
	WriteRegStr HKLM "${RegSysUnKey}" "DisplayName" "${Title}"
	WriteRegStr HKLM "${RegSysUnKey}" "DisplayVersion" "${Version}"
	WriteRegStr HKLM "${RegSysUnKey}" "Publisher" "${Vendor}"
	WriteRegStr HKLM "${RegSysUnKey}" "URLInfoAbout" "${URL}"
	WriteRegStr HKLM "${RegSysUnKey}" "DisplayIcon" "$INSTDIR\${Target}.exe"
	WriteRegStr HKLM "${RegSysUnKey}" "UninstallString" "$INSTDIR\Uninstall.exe"
	WriteRegDWORD HKLM "${RegSysUnKey}" "NoModify" 1
	WriteRegDWORD HKLM "${RegSysUnKey}" "NoRepair" 1
	;file type entry for .tsptask
	WriteRegStr HKCR ".tsptask" "" "TSP.Task"
	WriteRegStr HKCR "TSP.Task" "" "TSP Task"
	WriteRegDWORD HKCR "TSP.Task" "EditFlags" 65536
	WriteRegStr HKCR "TSP.Task\shell\open\command" "" "$\"$INSTDIR\${Target}.exe$\" $\"%1$\" "
	;ask for reboot to register file type
	SetRebootFlag true
SectionEnd

;-- Uninstall section --
Section "Uninstall"
	;uninstalling distribution
	Delete /REBOOTOK "$INSTDIR\${Target}.exe"
	Delete /REBOOTOK "$INSTDIR\Uninstall.exe"
	Delete /REBOOTOK "$INSTDIR\mingwm10.dll"
	Delete /REBOOTOK "$INSTDIR\QtCore4.dll"
	Delete /REBOOTOK "$INSTDIR\QtGui4.dll"
	Delete /REBOOTOK "$INSTDIR\QtSvg4.dll"
	Delete /REBOOTOK "$INSTDIR\COPYING.txt"
	RMDir /r /REBOOTOK "$INSTDIR\Examples"
	RMDir /r /REBOOTOK "$INSTDIR\Translations"
	RMDir  /REBOOTOK "$INSTDIR"
	;uninstalling start menu entries
	ReadRegStr $StartMenuDir HKLM "${RegKey}" "${RegSMPath}"
	Delete /REBOOTOK "$SMPROGRAMS\$StartMenuDir\${Title}.lnk"
	Delete /REBOOTOK "$SMPROGRAMS\$StartMenuDir\Uninstall.lnk"
	RMDir  "$SMPROGRAMS\$StartMenuDir"
	;cleaning registry
	DeleteRegValue HKLM "${RegKey}" "${RegInstPath}"
	DeleteRegValue HKLM "${RegKey}" "${RegSMPath}"
	DeleteRegKey HKLM "${RegSysUnKey}"
	DeleteRegKey HKCR "TSP.Task"
	DeleteRegKey HKCR ".tsptask"
	;ask for reboot to unregister file type
	SetRebootFlag true
SectionEnd

;-- Installer setup --
OutFile "${Target}-${Version}-setup.exe"
Name "${Title}"
CRCCheck on
XPStyle on
InstallDir "$PROGRAMFILES\${Title}"
InstallDirRegKey HKLM "${RegKey}" "${RegInstPath}"
VIAddVersionKey "ProductName"     "${Title}"
VIAddVersionKey "ProductVersion"  "${Version}"
VIAddVersionKey "CompanyName"     "${Vendor}"
VIAddVersionKey "LegalCopyright"  "(C) 2008-2010 ${Vendor}"
VIAddVersionKey "FileVersion"     "${Version}.0.1"
VIAddVersionKey "FileDescription" "Installer for TSP Flaming"
VIProductVersion "${Version}.0.1"
